CNX LiteZip Library
===================

This is a python library for working with the litezip file format, which is a Connexions cut down version of the completezip export file format.

This library contains tools for working with the litezip file structure. It also contains tools for converting a completezip to litezip.

License
-------

This software is subject to the provisions of the GNU Affero General
Public License Version 3.0 (AGPL). See license.txt for details.
Copyright (c) 2016 Rice University
